@@ -34,13 +34,12 @@ fieldhash my %maxlevel     => 'maxlevel';
 fieldhash my %minlevel     => 'minlevel';
 fieldhash my %report_items => 'report_items';
 fieldhash my %report_stt   => 'report_stt';
-fieldhash my %result       => 'result';
 fieldhash my %stt_file     => 'stt_file';
 fieldhash my %timeout      => 'timeout';
 fieldhash my %type         => 'type';
 fieldhash my %utils        => 'utils';
 
-our $VERSION = '1.00';
+our $VERSION = '1.02';
 
 # --------------------------------------------------
 
@@ -277,12 +276,11 @@ sub _init
 	$$arg{input_file}   ||= ''; # Caller can set.
 	$$arg{items}        = Set::Array -> new;
 	$$arg{lexed_file}   ||= '';       # Caller can set.
-	$$arg{logger}       ||= defined($$arg{logger}) ? $$arg{logger} : undef; # Caller can set.
+	$$arg{logger}       = defined($$arg{logger}) ? $$arg{logger} : undef; # Caller can set.
 	$$arg{maxlevel}     ||= 'notice'; # Caller can set.
 	$$arg{minlevel}     ||= 'error';  # Caller can set.
 	$$arg{report_items} ||= 0;        # Caller can set.
 	$$arg{report_stt}   ||= 0;        # Caller can set.
-	$$arg{result}       = 0;
 	$$arg{stt_file}     ||= ''; # Caller can set.
 	$$arg{timeout}      ||= 10; # Caller can set.
 	$$arg{type}         ||= ''; # Caller can set.
@@ -342,7 +340,8 @@ sub _process
 
 	$self -> log(debug => 'Graph text: ' . $self -> graph_text);
 
-	my($died) = '';
+	my($died)   = '';
+	my($result) = 0; # Default to success.
 
 	try
 	{
@@ -363,7 +362,7 @@ sub _process
 
 		alarm $self -> timeout;
 
-		$self -> result($self -> dfa -> run);
+		$result = $self -> dfa -> run;
 	}
 	catch
 	{
@@ -376,11 +375,12 @@ sub _process
 
 	if ($died)
 	{
+		$result = 1;
+
 		$self -> log(error => $died);
-		$self -> result(1);
 	}
 
-	if ($self -> result == 0)
+	if ($result == 0)
 	{
 		$self -> items -> push(@{$self -> dfa -> items});
 		$self -> report if ($self -> report_items);
@@ -390,11 +390,11 @@ sub _process
 		$self -> generate_lexed_file($file_name) if ($file_name);
 	}
 
-	$self -> log(info => $self -> result ? 'Fail' : 'OK');
+	$self -> log(info => $result ? 'Fail' : 'OK');
 
 	# Return 0 for success and 1 for failure.
 
-	return $self -> result;
+	return $result;
 
 } # End of _process.
 
@@ -514,7 +514,7 @@ sub _read_internal_file
 sub report
 {
 	my($self)   = @_;
-	my($format) = '%4s  %-4s  %-16s';
+	my($format) = '%4s  %-16s  %s';
 
 	$self -> log(notice => sprintf($format, 'Item', 'Type', 'Value') );
 
@@ -698,6 +698,14 @@ The default means the file is not written.
 
 See the distro for data/*.lex.
 
+=item o logger => $aLoggerObject
+
+Specify a logger compatible with L<Log::Handler>, for the lexer to use.
+
+Default: A logger of type L<Log::Handler> which writes to the screen.
+
+To disable logging, just set 'logger' to the empty string (not undef).
+
 =item o maxlevel => $logOption1
 
 This option affects L<Log::Handler>.
@@ -877,11 +885,13 @@ Calls $self -> logger -> $level($s) if ($self -> logger).
 
 =head2 logger([$logger_object])
 
+'logger' is a parameter to L</new()>. See L</Constructor and Initialization> for details.
+
 Here, the [] indicate an optional parameter.
 
 Get or set the logger object.
 
-To disable logging, just set 'logger' to the empty string, in the call to L</new()>.
+To disable logging, just set 'logger' to the empty string (not undef), in the call to L</new()>.
 
 This logger is passed to L<GraphViz2::Marpa::Lexer::DFA>.
 
@@ -967,8 +977,30 @@ The [] indicate an optional parameter.
 
 Get or set the value which determines what type of 'stt_file' is read.
 
+=head2 utils([$aUtilsObject])
+
+Here, the [] indicate an optional parameter.
+
+Get or set the utils object.
+
+Default: A object of type L<GraphViz2::Marpa::Utils>.
+
 =head1 FAQ
 
+=head2 Why doesn't the lexer/parser handle my HTML-style labels?
+
+Traps for young players:
+
+=over 4
+
+=item o The <br /> component must include the '/'. <br align='center'> is not accepted by Graphviz
+
+=item o The <br />'s attributes must use single quotes because output files use CSV with double quotes
+
+=back
+
+See data/38.* for good examples.
+
 =head2 Where are the scripts documented?
 
 In L<GraphViz2::Marpa/Scripts>.
@@ -1117,6 +1149,10 @@ This means that no output file, e.g. *.lex, *.parse or *.rend, will ever retain
 
 Perhaps. Perfection is an extra-cost option... The cost is unknown, but huge donations are welcome.
 
+Actually, according to DOT's HTML-like label definition, L<http://www.graphviz.org/content/node-shapes#html>
+you can use <...> instead of "..." to delimit text labels. The lexer as of V 1.02 does not handle this case.
+That is, the code only recognizes HTML-like labels which are delimited with '<<' and '>>'.
+
 =back
 
 =head1 Machine-Readable Change Log
@@ -1155,15 +1191,15 @@ __DATA__
 @@ stt
 
 Start,Accept,State,Event,Next,Entry,Exit,Regexp,Interpretation
-Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",ID
-,,,(?:graph|digraph),graph_id,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",: + ID
+Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",ID
+,,,(?:graph|digraph),graph_id,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",: + ID
 ,,,\/\*.*?\*\/,initial,,,\/\*.*?\*\/,
-,,,\s+,initial,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",: + ID + : + Compass point
+,,,\s+,initial,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",: + ID + : + Compass point
 ,,,,,,,:(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9]),: + Compass point
 ,,graph,(?:graph|digraph),graph_id,,save_prefix,(?:->|--),Edge
 ,,,\s+,graph,,,,
 ,,,,,,,,
-,,graph_id,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",open_brace,,save_graph_id,,
+,,graph_id,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",open_brace,,save_graph_id,,
 ,,,{,statement_list_1,,,,
 ,,,\/\*.*?\*\/,graph_id,,,,
 ,,,\s+,graph_id,,,,
@@ -1177,7 +1213,7 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,\s+,start_statement,,,,
 ,,,,,,,,
 ,Yes,statement_list_1,subgraph,graph_id,,save_id_1,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
 ,,,(?:->|--),edge_id,,,,
 ,,,(?:\[),attribute_list,,,,
 ,,,{,statement_list_2,,,,
@@ -1187,7 +1223,7 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,\s+,statement_list_1,,,,
 ,,,,,,,,
 ,Yes,statement_list_2,subgraph,graph_id,,save_id_1,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
 ,,,(?:->|--),edge_id,,,,
 ,,,(?:\[),attribute_list,,,,
 ,,,{,statement_list_1,,,,
@@ -1198,9 +1234,9 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,,,,,,
 ,,id_a,subgraph,graph_id,,save_id_2,,
 ,,,:(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9]),statement_list_1,,,,
-,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",statement_list_1,,,,
-,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",statement_list_1,,,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_b,,,,
+,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",statement_list_1,,,,
+,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",statement_list_1,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_b,,,,
 ,,,{,statement_list_1,,,A stand-alone {,
 ,,,},end_statement,,,,
 ,,,(?:->|--),id_b,,,,
@@ -1212,9 +1248,9 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,,,,,,
 ,,id_b,subgraph,graph_id,,save_id_2,,
 ,,,:(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9]),statement_list_1,,,,
-,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",statement_list_1,,,,
-,,,":(?:""[^""]+""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",statement_list_1,,,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
+,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*)):(?:n|ne|e|se|s|sw|w|nw|c|_)(?![a-zA-Z_0-9])",statement_list_1,,,,
+,,,":(?:""[^""]+""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",statement_list_1,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
 ,,,{,statement_list_1,,,A stand-alone {,
 ,,,},end_statement,,,,
 ,,,(?:->|--),id_a,,,,
@@ -1225,26 +1261,26 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,\s+,id_b,,,,
 ,,,,,,,,
 ,,edge_id,subgraph,id_a,,save_id_1,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
 ,,,(?:->|--),statement_list_1,,,,
 ,,,},end_statement,,,,
 ,,,\/\*.*?\*\/,edge_id,,,,
 ,,,\s+,edge_id,,,,
 ,,,,,,,,
-,,attribute_list,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_a,,save_attribute,,
+,,attribute_list,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_a,,save_attribute,,
 ,,,],statement_list_1,,,,
 ,,,},statement_list_1,,,,
 ,,,\/\*.*?\*\/,attribute_list,,,,
 ,,,\s+,attribute_list,,,,
 ,,,,,,,,
-,,attribute_a,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_b,,save_attribute,,
+,,attribute_a,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_b,,save_attribute,,
 ,,,=,attribute_b,,,,
 ,,,",",attribute_list,,,,
 ,,,],statement_list_1,,,,
 ,,,\/\*.*?\*\/,attribute_a,,,,
 ,,,\s+,attribute_a,,,,
 ,,,,,,,,
-,,attribute_b,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_a,,save_attribute,,
+,,attribute_b,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",attribute_a,,save_attribute,,
 ,,,=,attribute_a,,,,
 ,,,",",attribute_list,,,,
 ,,,],statement_list_1,,,,
@@ -1252,7 +1288,7 @@ Yes,,initial,strict,graph,,save_prefix,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0
 ,,,\s+,attribute_b,,,,
 ,,,,,,,,
 ,Yes,end_statement,subgraph,graph_id,,save_id_1,,
-,,,"(?:""[^""]*""|<[^>]*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
+,,,"(?:""[^""]*""|<\s*<.*?>\s*>|[a-zA-Z_][a-zA-Z_0-9]*|-?(?:\.[0-9]+|[0-9]+(?:\.[0-9])*))",id_a,,,,
 ,,,(?:->|--),edge_id,,,,
 ,,,\[,attribute_list,,,,
 ,,,{,statement_list_1,,,,
